@@ -19,6 +19,8 @@ from pyaxiom.netcdf.dataset import EnhancedDataset
 
 def get_type(obj):
     if hasattr(obj, 'dtype'):
+        if obj.dtype == object:
+            return str
         return obj.dtype
     elif isinstance(obj, (tuple, list)):
         return getattr(obj[0], 'dtype', type(obj[0]))
@@ -558,7 +560,7 @@ def get_dataframe_from_variable(nc, data_var):
         except AttributeError:
             continue
 
-    times  = netCDF4.num2date(time_var[:], units=time_var.units)
+    times  = netCDF4.num2date(time_var[:], units=time_var.units, calendar=getattr(time_var, 'calendar', 'standard'))
     original_times_size = times.size
 
     if depth_var is None and hasattr(data_var, 'sensor_depth'):
